<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       firehawkcrm.com
 * @since      1.0.0
 *
 * @package    Fcrm_Service
 * @subpackage Fcrm_Service/public/partials
 */
?>
<?php $fcrmDefaultImageUrl = get_option('fcrm_service_default_image'); ?>
<?php
if (function_exists('current_location') == false) {
  function current_location()
  {
      if (isset($_SERVER['HTTPS']) &&
          ($_SERVER['HTTPS'] == 'on' || $_SERVER['HTTPS'] == 1) ||
          isset($_SERVER['HTTP_X_FORWARDED_PROTO']) &&
          $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https') {
          $protocol = 'https://';
      } else {
          $protocol = 'http://';
      }
      return $protocol . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
  }
}
?>
<!-- This file should primarily consist of HTML with a little bit of PHP. -->
<div class="firehawk-crm">
  <?php
    if (sizeof($days) > 0) {
      echo '<div class="firehawk-crm-grid">';

      foreach ($days as $day => $innerArray) {
        $columnDate = new DateTime($innerArray[0]->serviceDateTime);
        echo '<div class="grid-column"><h3>'. $columnDate->format('D jS F') .'</h3>';

        foreach($innerArray as $innerRow => $client) {
          echo '<div class="grid-item">';
          if (isset($client->displayImage)) {
            echo '<div class="top-img" style="background-image: url(' . $client->displayImage . ')"></div>';
          } else if ($fcrmDefaultImageUrl && strlen($fcrmDefaultImageUrl)) {
            echo '<div class="top-img" style="background: url(' . $fcrmDefaultImageUrl . ');background-size: cover;background-position: center;"></div>';
          } else {
            echo '<div class="top-img" style="background: #f1f1f1;"></div>';
          }

          echo '<div class="content">';

          // Title
          echo '<div class="title">'.$client->fullName.'</div>';

          // Dates
          echo '<div class="dates">';
          if (isset($client->clientDateOfBirth) && isset($client->clientDateOfDeath)) {
            $date1 = new DateTime($client->clientDateOfBirth);
            $date2 = new DateTime($client->clientDateOfDeath);
            echo $date1->format('Y') . " - " . $date2->format('Y');
          } elseif (isset($client->clientDateOfDeath)) {
            $date1 = new DateTime($client->clientDateOfDeath);
            echo " - " . $date1->format('Y');

          }
          echo '</div>';

          // Service date
          $serviceTime = null;
          if (isset($client->serviceDateTime)) {
            echo '<div class="service-date"><strong>';
            $todayDate = new DateTime();
            $serviceTime = new DateTime($client->serviceDateTime);
            $interval = $todayDate->diff($serviceTime);
            echo $serviceTime->format('D j F g:i a');
            echo '</strong></div>';
          }

          // Venue
          $locationOfFuneral = "";
          if (isset($client->serviceVenue) && isset($client->serviceVenue->googleLink)) {
            echo '<a href="' . urldecode($client->serviceVenue->googleLink) . '" target="_blank" class="venue">';
            if (isset($client->serviceVenue) && isset($client->serviceVenue->name)) {
              echo $client->serviceVenue->name . "</br>";
              $locationOfFuneral = $locationOfFuneral . " " . $client->serviceVenue->name;
            }
            if (isset($client->serviceVenue) && isset($client->serviceVenue->address)) {
              echo $client->serviceVenue->address;
              $locationOfFuneral = $locationOfFuneral . " " . $client->serviceVenue->address;
            }
            echo '</a>';
          } else {
            echo '<div class="venue">';
            if (isset($client->serviceVenue) && isset($client->serviceVenue->name)) {
              echo $client->serviceVenue->name . ",";
              $locationOfFuneral = $locationOfFuneral . " " . $client->serviceVenue->name;
            }
            if (isset($client->serviceVenue) && isset($client->serviceVenue->address)) {
              echo $client->serviceVenue->address;
              $locationOfFuneral = $locationOfFuneral . " " . $client->serviceVenue->address;
            }
            echo '</div>';
          }

          $locationOfFuneral = trim($locationOfFuneral);
          $locationOfFuneral = str_replace(",","\,",$locationOfFuneral);
          $serviceEndTime = clone $serviceTime;
          date_add($serviceEndTime, date_interval_create_from_date_string('1 hour'));

          if (isset($detailPage)) {
            $shareUrl = current_location().'/'.$detailPage.'/?id='.$client->id;
          }

          include( plugin_dir_path( __FILE__ ) . 'service-buttons.php');
          ?>
          <?php

          echo '</div>';
          echo '</div>';
        }
        echo '</div>';
      }
      echo '</div>';
    } else {
      echo '<div class="empty-message">No upcoming services</div>';
    }
    ?>
</div>

<script type="text/javascript">
  jQuery('.firehawk-crm .firehawk-crm-grid .service-buttons-group a.open-modal').click(function(event) {
    jQuery(this).modal({
      fadeDuration: 250
    });
    return false;
  });
</script>

<script>
jQuery('.firehawk-crm .firehawk-crm-grid .service-buttons-group a.social-share').each(function() {
  var tippyButton = this;
  var menu = jQuery(this).next(".social-menu")[0]
  var activeClipboard = null
  var tip = tippy(tippyButton, {
    content: menu,
    trigger: 'click',
    interactive: true,
    onShown(instance) {
      window.Sharer.init();
      var copyBtn = jQuery(menu).find(".copy-btn")[0];
      if (copyBtn) {
        activeClipboard = new ClipboardJS(copyBtn);
      }
    },
    onHide(instance) {
      if (activeClipboard) {
        activeClipboard.destroy()
        activeClipboard = null
      }
    }
  });

  jQuery(menu).children(".button").click(function() {
    if (tip) {
      setTimeout(function() {
        tip.hide();
      }, 200);
    }
  })
});
</script>

<?php
if (function_exists('service_buttons_check') == false) {
  include( plugin_dir_path( __FILE__ ) . 'service-buttons-functions.php');
}
?>
